@@ -239,15 +239,12 @@ rsvg_text_handler_characters (RsvgSaxHandler *self, const xmlChar *ch, int len)
 	g_free (string);
 	
 #if ENABLE_TEXT_DECOR
-	if (state->font_decor & TEXT_OVERLINE) {
+	if (state->font_decor & TEXT_OVERLINE)
 		rsvg_draw_hline (ctx, 0, line_ink_rect.width, line_ink_rect.y - line_ink_rect.height);
-  }
-	if (state->font_decor & TEXT_UNDERLINE) {
+	if (state->font_decor & TEXT_UNDERLINE)
 		rsvg_draw_hline (ctx, 0, line_ink_rect.width, line_ink_rect.y);
-	}
-	if (state->font_decor & TEXT_STRIKE) {
+	if (state->font_decor & TEXT_STRIKE)
 		rsvg_draw_hline (ctx, 0, ink_rect.width, line_ink_rect.y - (line_ink_rect.height/2));
-	}
 #endif
 	
 	state->text_offset += line_ink_rect.width;
@@ -260,7 +257,7 @@ rsvg_start_tspan (RsvgHandle *ctx, const xmlChar **atts)
 	double affine[6] ;
 	double x, y, dx, dy;
 	RsvgState *state;
-	const char * klazz = NULL;
+	const char * klazz = NULL, * id = NULL;
 	x = y = dx = dy = 0.;
 	
   state = &ctx->state[ctx->n_state - 1];
@@ -279,6 +276,8 @@ rsvg_start_tspan (RsvgHandle *ctx, const xmlChar **atts)
 					  dy = rsvg_css_parse_normalized_length ((char *)atts[i + 1], ctx->dpi, (gdouble)ctx->height, state->font_size);
 				  else if (!strcmp ((char *)atts[i], "class"))
 					  klazz = (const char *)atts[i + 1];
+				  else if (!strcmp ((char *)atts[i], "id"))
+					  id = (const char *)atts[i + 1];
 			  }
 	  }
   
@@ -291,7 +290,7 @@ rsvg_start_tspan (RsvgHandle *ctx, const xmlChar **atts)
 		  art_affine_translate (affine, x, y);
 		  art_affine_multiply (state->affine, affine, state->affine);
 	  }
-  rsvg_parse_style_attrs (ctx, "tspan", klazz, atts);
+  rsvg_parse_style_attrs (ctx, "tspan", klazz, id, atts);
 }
 
 static void
@@ -313,7 +312,7 @@ rsvg_text_handler_start (RsvgSaxHandler *self, const xmlChar *name,
   
 	/* this should be the only thing starting inside of text */
 	if (!strcmp ((char *)name, "tspan"))
-    rsvg_start_tspan (ctx, atts);
+		rsvg_start_tspan (ctx, atts);
 }
 
 static void
@@ -349,7 +348,7 @@ rsvg_start_text (RsvgHandle *ctx, const xmlChar **atts)
 	int i;
 	double affine[6] ;
 	double x, y, dx, dy;
-	const char * klazz = NULL;
+	const char * klazz = NULL, * id = NULL;
 	RsvgState *state;
 	
 	RsvgSaxHandlerText *handler = g_new0 (RsvgSaxHandlerText, 1);
@@ -377,6 +376,8 @@ rsvg_start_text (RsvgHandle *ctx, const xmlChar **atts)
 						dy = rsvg_css_parse_normalized_length ((char *)atts[i + 1], ctx->dpi, (gdouble)ctx->height, state->font_size);
 					else if (!strcmp ((char *)atts[i], "class"))
 						klazz = (const char *)atts[i + 1];
+					else if (!strcmp ((char *)atts[i], "id"))
+						id = (const char *)atts[i + 1];
 				}
 		}
 
@@ -386,7 +387,7 @@ rsvg_start_text (RsvgHandle *ctx, const xmlChar **atts)
 	art_affine_translate (affine, x, y);
 	art_affine_multiply (state->affine, affine, state->affine);
 	
-	rsvg_parse_style_attrs (ctx, "text", klazz, atts);
+	rsvg_parse_style_attrs (ctx, "text", klazz, id, atts);
 	
 	handler->parent = ctx->handler;
 	ctx->handler = &handler->super;
